import { useParams } from "wouter";
import { useState } from "preact/hooks";
import { useQuery } from "react-query";
import { fetchUserInfo, Reminder } from "../../api";
import { DateTime } from "luxon";
import { CreateButtonRow } from "./ButtonRow/CreateButtonRow";
import { TopBar } from "./TopBar";
import { Message } from "./Message";
import { Settings } from "./Settings";
import { ReminderContext } from "./ReminderContext";

function defaultReminder(): Reminder {
    return {
        attachment: "",
        attachment_name: "",
        avatar: "",
        channel: "",
        content: "",
        embed_author: "",
        embed_author_url: "",
        embed_color: 0,
        embed_description: "",
        embed_fields: [],
        embed_footer: "",
        embed_footer_url: "",
        embed_image_url: "",
        embed_thumbnail_url: "",
        embed_title: "",
        enabled: true,
        expires: null,
        interval_days: null,
        interval_months: null,
        interval_seconds: null,
        name: "",
        restartable: false,
        tts: false,
        uid: "",
        username: "",
        utc_time: DateTime.now(),
    };
}

export const CreateReminder = () => {
    const [reminder, setReminder] = useState(defaultReminder);
    const [collapsed, setCollapsed] = useState(false);

    return (
        <ReminderContext.Provider value={[reminder, setReminder]}>
            <div class={collapsed ? "reminderContent is-collapsed" : "reminderContent"}>
                <TopBar
                    toggleCollapsed={() => {
                        setCollapsed(!collapsed);
                    }}
                />
                <div class="columns reminder-settings">
                    <Message />
                    <Settings />
                </div>
                <CreateButtonRow />
            </div>
        </ReminderContext.Provider>
    );
};
